Trait frame::traits::tokens::nonfungibles::Create
pub trait Create<AccountId>: Inspect<AccountId> {
// Required method
fn create_collection(
collection: &Self::CollectionId,
who: &AccountId,
admin: &AccountId
) -> Result<(), DispatchError>;
}Expand description
Trait for providing the ability to create collections of nonfungible items.
Required Methods
fn create_collection(
collection: &Self::CollectionId,
who: &AccountId,
admin: &AccountId
) -> Result<(), DispatchError>
fn create_collection( collection: &Self::CollectionId, who: &AccountId, admin: &AccountId ) -> Result<(), DispatchError>
Create a collection of nonfungible items to be owned by who and managed by admin.